@@ -1,7 +1,8 @@
 import pathlib
+from typing import Union
 
 
-def resolve_qt_path(path: str | pathlib.Path) -> str:
+def resolve_qt_path(path: Union[str, pathlib.Path]) -> str:
     """Convert a path to a string compatible with Qt's path-using methods."""
     if isinstance(path, str):
         path = pathlib.Path(path)
